@@ -1,2 +1,6 @@
 # Forked from https://github.com/ioc-fang/ioc_fanger
 from .ioc_fanger import fang
+
+__all__ = [
+    "fang",
+]
